@@ -360,15 +360,24 @@ public class BasicInformationView extends Composite implements FormValidator {
 				listOfContributorsView = new ArrayList<CreatorsFormView>();
 
 			// ADDING AUTHORS
-			List<? extends ZenodoAuthor> authors = zenodoItem.getMetadata().getCreators();
-			GWT.log("Adding creators: " + authors);
-			CreatorsFormView authorView = new CreatorsFormView(authors, ZenodoCreator.class);
-			listOfCreatorsView.add(authorView);
+			try {
+				List<? extends ZenodoAuthor> authors = zenodoItem.getMetadata().getCreators();
+				GWT.log("Adding creators: " + authors);
+				CreatorsFormView authorView = new CreatorsFormView(authors, ZenodoCreator.class, zenodoItem.getMetadata().getContributorsTypes());
+				listOfCreatorsView.add(authorView);
+			}catch (Exception e) {
+				//silent
+				e.printStackTrace();
+			}
 
-			List<? extends ZenodoAuthor> contributors = zenodoItem.getMetadata().getContributors();
-			GWT.log("Adding contributors: " + contributors);
-			CreatorsFormView contributorView = new CreatorsFormView(contributors, ZenodoContributor.class);
-			listOfContributorsView.add(contributorView);
+			try {
+				List<? extends ZenodoAuthor> contributors = zenodoItem.getMetadata().getContributors();
+				GWT.log("Adding contributors: " + contributors);
+				CreatorsFormView contributorView = new CreatorsFormView(contributors, ZenodoContributor.class, zenodoItem.getMetadata().getContributorsTypes());
+				listOfContributorsView.add(contributorView);
+			}catch (Exception e) {
+				e.printStackTrace();
+			}
 
 			for (CreatorsFormView cfv : listOfCreatorsView) {
 				fieldset_basic_informations.add(cfv);
